==> deepin-system-monitor-1.3.6-1-x86_64.pkg.tar.xz: usr/share/dman/deepin-system-monitor/en_US/index.md <==
# Deepin System Monitor |../common/monitor.svg|

## Overview|../common/icon_overview.svg|

Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status. You can also search, suspend, resume and end your processes by it.


## Basic Operations|../common/icon_basicfuncton.svg|

### Status Monitoring

Deepin System Monitor can monitor the CPU, memory and network status of your system:

- CPU monitoring, you can view the CPU usage and usage trends through graphics, number and curve.
- Memory monitoring, you can view the memory size and real-time usage, total swap space and real-time usage.
- Network monitoring, you can view the download and upload speed,total download and upload size as well as the network status trend.

![1|status1](png/status1.png)


### Process Management

#### Switch Process Tabs

Click on the top right tabs on interface to switch to view application processes, user's processes and all processes.

- Click on ![application](icon/application.png) to view the application processes.
- Click on ![user](icon/user.png) to view the user's processes.
- Click on ![all](icon/all.png) to view all processes.

![1|status2](png/status2.png)

#### Adjust Process Order

You can adjust the process order by name, CPU, memory, disk write, disk read, download, upload and PID.

1. On Deepin System Monitor interface, click on the top tabs of process list to sort the processes.
2. Multiple clicks to sort from low to high or high to low.
3. Right click on the top tabs to check or uncheck.

![1|order](png/order.png)


#### Search Process

Type the process name in the top search box on Deepin System Monitor interface to search and quickly locate the process.

![1|search](png/search.png)

#### Force to End Process

1. On Deepin System Monitor interface, click the main menu.
2. Select **Force to end application**.
3. Click on the opened application window to end when the mouse becomes ![kill_cursor](icon/kill_cursor.png).
4. Click on **End application** in the pop-up window to confirm.

> ![notes](icon/notes.svg): You can only end GUI application process by clicking on **Force to end application**.


![1|force](png/force.png)

#### End Process

1. On Deepin System Monitor interface, right click on the process you want to end.
2. Select **End process**.
3. Click on **End process** in the pop-up window to confirm.

> ![notes](icon/notes.svg): You can select **End process** to end all processes.

![1|end](png/end.png)


#### Suspend/Continue Process

1. On Deepin System Monitor interface, right click on the process you want to suspend.
2. Select **Suspend process**.
3. The process will be suspended, and you can right click to select **Resume process** to resume it.

![1|suspend](png/suspend.png)


#### View Process Location

1. On Deepin System Monitor interface, right click on the process you want to view.
2. Select **View process location**.
3. The process command location will be opened.


#### View Process Properties

1. On Deepin System Monitor interface, right click on the process you want to view.
2. Select **Properties**.
3. You can view the process name, command line and start time.

![2|properties](png/properties.png)


## Main Menu|../common/icon_optionsetting.svg|

### Switch Theme

You can switch the theme of Deepin System Monitor.

1. On Deepin System Monitor interface, click on ![icon_menu](icon/icon_menu.svg) .
2. Click on **Dark theme**.
3. Switch to dark theme from the default light theme.

![1|theme](png/theme.png)



### Help

You can click to view the manual, which will help you further know and use Deepin System Monitor.

1. On Deepin System Monitor interface, click on ![icon_menu](icon/icon_menu.svg) .
2. Click on **Help**.
3. View the manual.


![1|help](png/help.png)


### About

You can click to view the version description.

1. On Deepin System Monitor interface, click on ![icon_menu](icon/icon_menu.svg).
2. Click on **About**.
3. View the version description.

![0|about](png/about.png)


### Exit

You can click to exit Deepin System Monitor.

1. On Deepin System Monitor interface, click on ![icon_menu](icon/icon_menu.svg).
2. Click on **Exit** to exit.

==> deepin-system-monitor-1.4.4-1-x86_64.pkg.tar.xz: usr/share/dman/deepin-system-monitor/en_US/index.md <==
# Deepin System Monitor |../common/monitor.svg|

## Overview|../common/icon_overview.svg|

Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status. You can also search, suspend, resume and end your processes by it.


## Basic Operations|../common/icon_basicfuncton.svg|

### Status Monitoring

Deepin System Monitor can monitor the CPU, memory, network and disk status of your system:

- CPU monitoring, you can view the CPU usage and usage trends through graphics, number and curve.
- Memory monitoring, you can view the memory size and real-time usage, total swap space and real-time usage.
- Network monitoring, you can view the download and upload speed, total download and upload size as well as the network status trend.
- Disk monitoring, you can view the disk read and write speed and its trends.

![1|status1](jpg/status1.jpg)

> ![notes](icon/notes.svg): If you cannot find disk status on the interface, please switch to [Compact mode](#Compact mode) in main menu.

### Process Management

#### Switch Process Tabs

Click on the top right tabs on interface to switch to view application processes, user's processes and all processes.

- Click on ![application](icon/application.png) to view the application processes.
- Click on ![user](icon/user.png) to view the user's processes.
- Click on ![all](icon/all.png) to view all processes.

![1|status2](jpg/status2.jpg)

#### Adjust Process Order

You can adjust the process order by name, CPU, memory, disk write, disk read, download, upload and PID.

1. On Deepin System Monitor interface, click on the top tabs of process list to sort the processes.
2. Multiple clicks to sort from low to high or high to low.
3. Right click on the top tabs to check or uncheck.

![1|order](jpg/order.jpg)


#### Search Process

Type the process name in the top search box on Deepin System Monitor interface to search and quickly locate the process.

![1|search](jpg/search.jpg)

#### End Process

1. On Deepin System Monitor interface, right click on the process you want to end.
2. Select **End process**.
3. Click on **End process** in the pop-up window to confirm.

> ![notes](icon/notes.svg): You can select **End process** to end all kinds of processes.

![1|end](jpg/end.jpg)

#### Force to End Process

1. On Deepin System Monitor interface, click the main menu.
2. Select **Force to end application**.
3. Click on the opened application window to end when the mouse becomes ![kill_cursor](icon/kill_cursor.png).
4. Click on **End application** in the pop-up window to confirm.

> ![notes](icon/notes.svg): You can only end GUI application process by clicking on **Force to end application**.


![1|force](jpg/force.jpg)

#### Suspend/Continue Process

1. On Deepin System Monitor interface, right click on the process you want to suspend.
2. Select **Suspend process**.
3. The process will be suspended, and you can right click to select **Resume process** to resume it.

![1|suspend](jpg/suspend.jpg)


#### View Process Location

1. On Deepin System Monitor interface, right click on the process you want to view.
2. Select **View process location**.
3. The process command location will be opened.


#### View Process Properties

1. On Deepin System Monitor interface, right click on the process you want to view.
2. Select **Properties**.
3. You can view the process name, command line and start time.

![2|properties](jpg/properties.jpg)


## Main Menu|../common/icon_optionsetting.svg|

### Switch Theme

You can switch the theme of Deepin System Monitor.

1. On Deepin System Monitor interface, click on ![icon_menu](icon/icon_menu.svg) .
2. Click on **Dark theme**.
3. Switch to dark theme from the default light theme.

![1|theme](jpg/theme.jpg)

### Compact mode

You can switch to compact mode if your screen cannot show all monitoring information, including CPU, memory, network and disk status.

1. On Deepin System Monitor interface, click on ![icon_menu](icon/icon_menu.svg) .

2. Click on **Compact mode**.

3. View all system information.

   ![1|compact](jpg/compact.jpg)

### Help

You can click to view the manual, which will help you further know and use Deepin System Monitor.

1. On Deepin System Monitor interface, click on ![icon_menu](icon/icon_menu.svg) .
2. Click on **Help**.
3. View the manual.





### About

You can click to view the version description.

1. On Deepin System Monitor interface, click on ![icon_menu](icon/icon_menu.svg).
2. Click on **About**.
3. View the version description.




### Exit

You can click to exit Deepin System Monitor.

1. On Deepin System Monitor interface, click on ![icon_menu](icon/icon_menu.svg).
2. Click on **Exit** to exit.
